AnnotationData class

Constructors

AnnotationData({required bool fromJson, required bool toEntity, required bool toJson, required bool fromEntity, required bool genericAugmented, String? hiveObjectName, required bool toHiveObject, required bool fromHiveObject})
const

Properties

fromEntity bool
final
fromHiveObject bool
final
fromJson bool
final
genericAugmented bool
final
hashCode int
The hash code for this object.
no setterinherited
hiveObjectName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toEntity bool
final
toHiveObject bool
final
toJson bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited