FieldMeta class
Field-level metadata extracted from constructor parameter annotations.
Supports:
@Default(value)-> defaultValue holds the literal representation.@JsonKey(name: 'foo')-> jsonKey holdsfoo.
Properties
- defaultValue → String?
-
final
- hasDefault → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- jsonKey → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited